"""SfePrapy CLI Help.
Usage:
    sfeprapy mcs0 [-p=<int>] [-f] [--template] <file_name>

Options:
    -f              to produce figure from the output file <file_name>.
    -p=<int>        to define number of processes for MCS, positive integer only.
    --template      to save example input file to <file_name>.
    -h --help       to show this message.

Commands:
    mcs0            Monte Carlo Simulation to solve equivalent time exposure in ISO 834 fire, method 0.
"""

from docopt import docopt


def main():
    import os

    arguments = docopt(__doc__)

    if 'mcs0' in arguments:
        import sfeprapy
        from sfeprapy.mcs0.__main__ import main as mcs0
        from sfeprapy.mcs0.__main__ import save_figure as mcs0_figure

        arguments['<file_name>'] = os.path.realpath(arguments['<file_name>'])

        if arguments['-f']:
            mcs0_figure(
                fp_mcs0_out=arguments['<file_name>']
            )
        elif arguments['--template']:
            with open(arguments['<file_name>'], 'w+') as f:
                f.write(sfeprapy.mcs0.EXAMPLE_INPUT_CSV)
            # DO NOT NEED CONFIGURATION FILE FOR CLI
            # import json
            # with open(os.path.join(os.path.dirname(arguments['<file_name>']), 'config.json'), 'w+') as f:
            #     json.dump(sfeprapy.mcs0.EXAMPLE_CONFIG_DICT, f)
        else:
            arguments['-p'] = arguments['-p'] or 2
            mcs0(
                fp_mcs_in=os.path.realpath(arguments['<file_name>']),
                n_threads=int(arguments['-p'])
            )
    else:
        print('instruction unclear.')



# -*- coding: utf-8 -*-

from sfeprapy.mcs0.mcs0_test import test_arg as test_mcs0_test_arg
from sfeprapy.mcs0.mcs0_test import test_standard_case as test_mcs0_test_standard_case
from sfeprapy.func.mcs_gen import test_dict_flatten as test_mcs_gen_dict_flatten
from sfeprapy.func.mcs_gen import test_random_variable_generator as test_mcs_gen_random_variable_generator
from sfeprapy.func.fire_parametric_ec import test_fire as test_fire_parametric_ec
from sfeprapy.func.fire_travelling import test_fire as test_fire_travelling
from sfeprapy.func.fire_travelling import test_fire_backup as test_fire_travelling_backup
from sfeprapy.func.fire_travelling import test_fire_multiple_beam_location as test_fire_travelling_multiple

test_mcs0_test_arg()
test_mcs0_test_standard_case()
test_mcs_gen_dict_flatten()
test_mcs_gen_random_variable_generator()
test_fire_parametric_ec()
test_fire_travelling()
test_fire_travelling_backup()
test_fire_travelling_multiple()
